@@ -2,7 +2,7 @@ package Test::ConfigFromFile::Command::moo;
 use Mouse;
 use YAML();
 
-extends qw(MouseX::App::Cmd::Command);
+extends 'MouseX::App::Cmd::Command';
 with 'MouseX::ConfigFromFile';
 
 =head1 NAME
