@@ -1,6 +1,6 @@
 package Test::MyCmd;
 use Mouse;
 
-extends qw(MouseX::App::Cmd);
+extends 'MouseX::App::Cmd';
 
 1;
